package org.kde.koala;
import org.kde.qt.*;


/** {@link KAnimWidget} emits these signals */
public interface KAnimWidgetSignals {
	void destroyed( QObject obj );
	void clicked();
}

